@@ -19,7 +19,12 @@ Rose::HTML::Form::Field::PhoneNumber::US->import_methods
   'deflate_value',
 );
 
-our $VERSION = '0.011';
+Rose::HTML::Form::Field::Compound->import_methods
+(
+  'name',
+);
+
+our $VERSION = '0.02';
 
 sub build_field
 {
@@ -140,7 +145,7 @@ numbers with separate fields for area code, exchange, and number.
 
 =head1 DESCRIPTION
 
-C<Rose::HTML::Form::Field::PhoneNumber::US::Split> is a compound field that
+L<Rose::HTML::Form::Field::PhoneNumber::US::Split> is a compound field that
 contains three separate text fields for US phone numbers: one each for area
 code, exchange, and number.  It inherits from both
 L<Rose::HTML::Form::Field::PhoneNumber::US> and
